==> nextcloud-app-deck-1%3A1.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/da.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Du har oprettet en ny tavle {board}",
    "{user} has created a new board {board}" : "{user} har oprettet en ny tavle {board}",
    "You have deleted the board {board}" : "Du har slettet tavlen {board}",
    "{user} has deleted the board {board}" : "{user} har slettet tavlen {board}",
    "You have restored the board {board}" : "Du har genskabt tavlen {board}",
    "{user} has restored the board {board}" : "{user} har genskabt tablen {board}",
    "You have shared the board {board} with {acl}" : "Du har delt tavlen {board} med {acl}",
    "{user} has shared the board {board} with {acl}" : "{user}  har delt tavlen {board} med {acl}",
    "You have removed {acl} from the board {board}" : "Du har fjernet {acl} fra tavlen {board}",
    "{user} has removed {acl} from the board {board}" : "{user} har fjernet {acl} fra tavlen {board}",
    "You have renamed the board {before} to {board}" : "Du har omdøbt tavlen {before} til {board}",
    "{user} has renamed the board {before} to {board}" : "{suer} har omdøbt tavlen {before} til {board}",
    "You have archived the board {board}" : "Du har arkiveret tavlen {board}",
    "{user} has archived the board {before}" : "{user} har arkiveret tavlen {before}",
    "You have unarchived the board {board}" : "Du har genskabt tavlen {board}",
    "{user} has unarchived the board {before}" : "{user} har genskabt tavlen {before}",
    "You have created a new list {stack} on board {board}" : "Du har oprettet en ny liste {stack} på tavlen {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} har oprettet en ny liste {stack} på tavlen {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Du har omdøbt liste {before} til {stack} på tavlen {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} har omdøbt liste {before} til {stack} på tavlen {board}",
    "You have deleted list {stack} on board {board}" : "Du har slettet liste {stack} på tavlen {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} har slettet liste {stack} på tavlen {board}",
    "You have created card {card} in list {stack} on board {board}" : "Du har oprettet kortet {card} i listen {stack} på tavlen {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} har oprettet kortet {card} i listen {stack} på tavlen {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Du har slettet kortet {card} i listen {stack} på tavlen {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} har slettet kortet {card} i listen {stack} på tavlen {board}",
    "You have renamed the card {before} to {card}" : "Du har omdøbt kortet {before} til {card}",
    "{user} has renamed the card {before} to {card}" : "{user} har omdøbt kortet {before} til {card}",
    "Deck" : "Opslag",
    "Changes in the <strong>Deck app</strong>" : "Ændringer i <strong>Opslags app'en</strong>",
    "Upcoming cards" : "Kommende kort",
    "Load more" : "Hent flere",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortet \"%s\" på \"%s\" er blevet tildelt dig af %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} har tilknyttet kortet {deck-card} på {deck-board} til dig.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nået sin forfaldsdato.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Kortet {deck-card} på {deck-board} har nået sin forfaldsdato.",
    "%s has mentioned you in a comment on \"%s\"." : " %s har nævnt dig i en kommentar på \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} har nævnt dig i en kommentar på {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Tavlen \"%s\" er blevet delt med dig af %s.",
    "{user} has shared {deck-board} with you." : "{user} har delt {deck-board} med dig.",
    "Deck board" : "Opslagstavle",
    "Deck boards, cards and comments" : "Opslagstavler, kort og kommentarer",
    "Create a new deck card" : "Opret et nyt opslagskort",
    "%s on %s" : "%s på %s",
    "Deck boards and cards" : "Opslagstavler og -kort",
    "No data was provided to create an attachment." : "Ingen data blev givet som kunne vedhæftes",
    "Finished" : "Færdiggjort",
    "To review" : "Til gennemgang",
    "Action needed" : "Handling påkrævet",
    "Later" : "Senere",
    "copy" : "kopiér",
    "To Do" : "To-do liste",
    "In Progress" : "I gang",
    "Done" : "Afsluttet",
    "The file was uploaded" : "Filen blev uploadet",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "The file was only partially uploaded" : "Filen blev kun delvist uploadet.",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "Could not write file to disk" : "Kunne ikke gemme filen",
    "A PHP extension stopped the file upload" : "En PHP udvidelse stoppede filupload.",
    "No file uploaded or file size exceeds maximum of %s" : "Ingen fil blev uploadet eller filstørrelsen er større end maksimum: %s.",
    "Card not found" : "Kort ikke fundet.",
    "Path is already shared with this card" : "Stien er allerede delt med dette kort.",
    "Invalid date, date format must be YYYY-MM-DD" : "Ikke gyldig dato - dato formatet skal være ÅÅÅÅ-MM-DD",
    "Personal planning and team project organization" : "Personlig planlægning og organisering af teamprojekter",
    "Card details" : "Kortdetaljer",
    "Add board" : "Tilføj tavle",
    "Select the board to link to a project" : "Vælg tavlen der skal linkes til et projekt",
    "Search by board title" : "Søg efter tavletitel",
    "Select board" : "Vælg tavle",
    "Select a board" : "Vælg en tavle",
    "No lists available" : "Ingen lister tilgængelige",
    "Select a list" : "Vælg en liste",
    "Move card" : "Flyt kort",
    "Select a card" : "Vælg et kort",
    "Cancel" : "Annuller",
    "Select the card to link to a project" : "Vælg kortet der skal linkes til et projekt",
    "Link to card" : "Link til kort",
    "File already exists" : "Filen findes allerede",
    "A file with the name {filename} already exists." : "En fil med navnet {filename} eksisterer allerede.",
    "Do you want to overwrite it?" : "Vil du overskrive?",
    "Overwrite file" : "Overskriv fil",
    "Keep existing file" : "Behold den eksisterende fil",
    "This board is read only" : "Denne tavle er skrivebeskyttet",
    "Drop your files to upload" : "Slip dine filer for at uploade",
    "Add card" : "Tilføj kort",
    "Archived cards" : "Arkiverede kort",
    "Add list" : "Tilføj liste",
    "List name" : "Listenavn",
    "Active filters" : "Aktive filtre",
    "Apply filter" : "Aktivér filter",
    "Filter by tag" : "Filtrer efter Tag",
    "Filter by assigned user" : "Filtrer efter tildelt bruger",
    "Unassigned" : "Ikke tildelt",
    "Open" : "Åbn",
    "Completed" : "Fuldført",
    "Filter by due date" : "Filtrer efter forfaldsdato",
    "Overdue" : "Overskredet",
    "Next 24 hours" : "De næste 24 timer",
    "Next 7 days" : "De næste 7 dage",
    "Next 30 days" : "De næste 30 dage",
    "No due date" : "Ingen forfaldsdato",
    "Clear filter" : "Ryd filter",
    "Hide archived cards" : "Skjul arkiverede kort",
    "Show archived cards" : "Vis arkiverede kort",
    "Toggle compact mode" : "Slå kompakt tilstand til/fra",
    "Open details" : "Mere information",
    "Details" : "Detaljer",
    "Loading board" : "Indlæser tavle",
    "Board not found" : "Tavle ikke fundet.",
    "Create a new list to add cards to this board" : "Opret en ny liste for at tilføje kort til denne tavle ",
    "Sharing" : "Deling",
    "Tags" : "Tags",
    "Deleted items" : "Slettede objekter",
    "Activity" : "Aktivitet",
    "Deleted lists" : "Slettede lister",
    "Undo" : "Fortryd",
    "Deleted cards" : "Sletttede kort",
    "No participants found" : "Ingen deltagere fundet",
    "Board owner" : "Ejer af tavlen",
    "(Group)" : "(Gruppe)",
    "Can edit" : "Kan redigere",
    "Can share" : "Kan dele",
    "Can manage" : "Kan administrere",
    "Owner" : "Ejer",
    "Delete" : "Slet",
    "Failed to create share with {displayName}" : "Kunne ikke oprette deling med {displayName}",
    "Transfer" : "Overførsel",
    "Archive all cards" : "Arkivér alle kort",
    "Delete list" : "Slet liste",
    "Archive all cards in this list" : "Arkivér alle kort på denne liste",
    "Add a new card" : "Tilføj et nyt kort",
    "Card name" : "Kortnavn",
    "List deleted" : "Liste slettet",
    "Edit" : "Redigér",
    "Add a new tag" : "Opret et nyt Tag",
    "title and color value must be provided" : "Titel- og farveværdi skal angives.",
    "Board name" : "Tavlenavn",
    "Members" : "Medlemmer",
    "Assign a user to this card…" : "Tildel en bruger til dette kort...",
    "Upload new files" : "Upload nye filer",
    "Share from Files" : "Del fra Filer",
    "Add this attachment" : "Tilføj denne vedhæftning",
    "Show in Files" : "Vis i Filer",
    "Download" : "Download",
    "Delete Attachment" : "Slet vedhæftning",
    "Restore Attachment" : "Genskab vedhæftning",
    "File to share" : "Fil til deling",
    "Invalid path selected" : "Ugyldig sti valgt.",
    "Open in sidebar view" : "Åben i sidebjælke visning",
    "Open in bigger view" : "Åben i større visning",
    "Attachments" : "Vedhæftede filer",
    "Comments" : "Kommentarer",
    "Modified" : "Ændret",
    "Created" : "Oprettet",
    "The title cannot be empty." : "Titlen må ikke være tom",
    "No comments yet. Begin the discussion!" : "Ingen kommentarer endnu. Begynd diskussionen!",
    "Save" : "Gem",
    "The comment cannot be empty." : "Kommentaren må ikke være tom.",
    "The comment cannot be longer than 1000 characters." : "Kommentaren må ikke være længere end 1000 tegn.",
    "In reply to" : "Som svar til",
    "Cancel reply" : "Annuller svar",
    "Reply" : "Besvar",
    "Update" : "Opdatér",
    "Created:" : "Oprettet:",
    "Description" : "Beskrivelse",
    "(Unsaved)" : "(Ikke gemt)",
    "(Saving…)" : "(Gemmer...)",
    "Formatting help" : "Hjælp til formatering",
    "Edit description" : "Rediger beskrivelse",
    "View description" : "Se beskrivelse",
    "Add Attachment" : "Tilføj vedhæftning",
    "Write a description …" : "Skriv en beskrivelse...",
    "Choose attachment" : "Vælg en vedhæftning",
    "Set a due date" : "Angiv en forfaldsdato",
    "Remove due date" : "Fjern forfaldsdato",
    "Mark as done" : "Marker som færdig",
    "Not done" : "Ikke færdig",
    "Unarchive card" : "Genaktiver kort",
    "Archive card" : "Arkivér kort",
    "Select Date" : "Vælg dato",
    "Assign a tag to this card…" : "Tilføj et Tag til dette kort ...",
    "(group)" : "(gruppe)",
    "Open link" : "Åben link",
    "Edit title" : "Rediger titel",
    "Assign to me" : "Tildel til mig",
    "Unassign myself" : "Fjern mig selv",
    "Delete card" : "Slet kort",
    "Card deleted" : "Kort slettet",
    "seconds ago" : "få sekunder siden",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Boost your productivity using Deck with keyboard shortcuts." : "Boost din produktivitet ved at anvende opslag med tastaturgenveje.",
    "Keyboard shortcut" : "Tastaturgenvej",
    "Action" : "Handling",
    "Shift" : "Shift",
    "Ctrl" : "Ctrl",
    "Search" : "Søg",
    "All boards" : "Alle tavler",
    "Archived boards" : "Arkiverede lister",
    "Shared with you" : "Delt med dig",
    "Deck settings" : "Opslagsindstillinger",
    "Use bigger card view" : "Brug større kort visning",
    "Show boards in calendar/tasks" : "Vis tavler i kalender/opgaver",
    "Cancel edit" : "Annuller redigering",
    "Board details" : "Tavledetaljer",
    "Edit board" : "Rediger liste",
    "Clone board" : "Klon tavle",
    "Unarchive board" : "Genaktiver tavle",
    "Archive board" : "Arkivér tavle",
    "Turn on due date reminders" : "Aktiver påmindelser om forfaldsdatoer",
    "Turn off due date reminders" : "Slå påmindelser om forfaldsdatoer fra",
    "Due date reminders" : "Påmindelser om forfaldsdatoer",
    "All cards" : "Alle kort",
    "Assigned cards" : "Tildelte kort",
    "No notifications" : "Ingen notifikationer",
    "Delete board" : "Slet tavle",
    "Board {0} deleted" : "Tavle {0} er slettet",
    "Only assigned cards" : "Kun tildelte kort",
    "No reminder" : "Ingen påmindelse",
    "An error occurred" : "Der opstod en fejl",
    "Delete the board?" : "Slet tavlen?",
    "Clone {boardTitle}" : "Klon {boardTitle}",
    "Clone cards" : "Klon kort",
    "Clone assignments" : "Kloningsopgaver",
    "Clone labels" : "Kloningslabels",
    "Clone due dates" : "Klon forfaldsdatoer",
    "Advanced options" : "Avancerede indstillinger",
    "Clone" : "Klon",
    "Loading filtered view" : "Indlæser filtreret visning",
    "Today" : "I dag",
    "Tomorrow" : "I morgen",
    "No due" : "Ikke forfalden",
    "No results found" : "Ingen resultater fundet",
    "Deck board {name}\n* Last modified on {lastMod}" : "Opslagstavle {name}\n* Senest ændret den {lastMod}",
    "Create card" : "Opret kort",
    "Close" : "Luk",
    "No upcoming cards" : "Ingen kommende kort",
    "upcoming cards" : "kommende kort",
    "Link to a board" : "Link til tavle",
    "Link to a card" : "Link til et kort",
    "Message from {author} in {conversationName}" : "Besked fra {author} i {conversationName}",
    "Something went wrong" : "Noget gik galt",
    "Failed to upload {name}" : "Kunne ikke uploade {name}",
    "Maximum file size of {size} exceeded" : "Maksimal filstørrelse {size} overskredet",
    "Error creating the share" : "Fejl ved oprettelse af delt drev",
    "Share with a Deck card" : "Del med et opslagskort",
    "Share {file} with a Deck card" : "Del {file} med et opslagskort",
    "Share" : "Del",
    "Personal" : "Personligt",
    "To do" : "To do",
    "Doing" : "Igang",
    "Example Task 3" : "Eksempel opgave 3",
    "Example Task 2" : "Eksempel opgave 2",
    "Example Task 1" : "Eksempel opgave 1",
    "Move card to another board" : "Flyt kort til en anden tavle"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.16.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/da.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Du har oprettet en ny tavle {board}",
    "{user} has created a new board {board}" : "{user} har oprettet en ny tavle {board}",
    "You have deleted the board {board}" : "Du har slettet tavlen {board}",
    "{user} has deleted the board {board}" : "{user} har slettet tavlen {board}",
    "You have restored the board {board}" : "Du har genskabt tavlen {board}",
    "{user} has restored the board {board}" : "{user} har genskabt tablen {board}",
    "You have shared the board {board} with {acl}" : "Du har delt tavlen {board} med {acl}",
    "{user} has shared the board {board} with {acl}" : "{user}  har delt tavlen {board} med {acl}",
    "You have removed {acl} from the board {board}" : "Du har fjernet {acl} fra tavlen {board}",
    "{user} has removed {acl} from the board {board}" : "{user} har fjernet {acl} fra tavlen {board}",
    "You have renamed the board {before} to {board}" : "Du har omdøbt tavlen {before} til {board}",
    "{user} has renamed the board {before} to {board}" : "{suer} har omdøbt tavlen {before} til {board}",
    "You have archived the board {board}" : "Du har arkiveret tavlen {board}",
    "{user} has archived the board {before}" : "{user} har arkiveret tavlen {before}",
    "You have unarchived the board {board}" : "Du har genskabt tavlen {board}",
    "{user} has unarchived the board {before}" : "{user} har genskabt tavlen {before}",
    "You have created a new list {stack} on board {board}" : "Du har oprettet en ny liste {stack} på tavlen {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} har oprettet en ny liste {stack} på tavlen {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Du har omdøbt liste {before} til {stack} på tavlen {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} har omdøbt liste {before} til {stack} på tavlen {board}",
    "You have deleted list {stack} on board {board}" : "Du har slettet liste {stack} på tavlen {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} har slettet liste {stack} på tavlen {board}",
    "You have created card {card} in list {stack} on board {board}" : "Du har oprettet kortet {card} i listen {stack} på tavlen {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} har oprettet kortet {card} i listen {stack} på tavlen {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Du har slettet kortet {card} i listen {stack} på tavlen {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} har slettet kortet {card} i listen {stack} på tavlen {board}",
    "You have renamed the card {before} to {card}" : "Du har omdøbt kortet {before} til {card}",
    "{user} has renamed the card {before} to {card}" : "{user} har omdøbt kortet {before} til {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Du har tilføjet en beskrivelse til kortet {card} i listen {stack} på tavlen {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} har tilføjet en beskrivelse til kortet {card} i listen {stack} på tavlen {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Du har opdateret beskrivelsen for kortet {card} i listen {stack} på tavlen {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} har opdateret beskrivelsen for kortet {card} i listen {stack} på tavlen {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Du har arkiveret kortet {card} i listen {stack} på tavlen {board}",
    "Deck" : "Opslag",
    "Changes in the <strong>Deck app</strong>" : "Ændringer i <strong>Opslags app'en</strong>",
    "The file was uploaded" : "Filen blev uploadet",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "The file was only partially uploaded" : "Filen blev kun delvist uploadet.",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "Could not write file to disk" : "Kunne ikke gemme filen",
    "A PHP extension stopped the file upload" : "En PHP udvidelse stoppede filupload.",
    "No file uploaded or file size exceeds maximum of %s" : "Ingen fil blev uploadet eller filstørrelsen er større end maksimum: %s.",
    "Upcoming cards" : "Kommende kort",
    "Load more" : "Hent flere",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortet \"%s\" på \"%s\" er blevet tildelt dig af %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} har tilknyttet kortet {deck-card} på {deck-board} til dig.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nået sin forfaldsdato.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Kortet {deck-card} på {deck-board} har nået sin forfaldsdato.",
    "%s has mentioned you in a comment on \"%s\"." : " %s har omtalt dig i en kommentar på \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} har omtalt dig i en kommentar på {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Tavlen \"%s\" er blevet delt med dig af %s.",
    "{user} has shared {deck-board} with you." : "{user} har delt {deck-board} med dig.",
    "Deck board" : "Opslagstavle",
    "Deck boards, cards and comments" : "Opslagstavler, kort og kommentarer",
    "Create a new deck card" : "Opret et nyt opslagskort",
    "Card comments" : "Kommentarer på kort",
    "%s on %s" : "%s på %s",
    "Deck boards and cards" : "Opslagstavler og -kort",
    "No data was provided to create an attachment." : "Ingen data blev givet som kunne vedhæftes",
    "Finished" : "Færdiggjort",
    "To review" : "Til gennemgang",
    "Action needed" : "Handling påkrævet",
    "Later" : "Senere",
    "copy" : "kopier",
    "To Do" : "To-do liste",
    "In Progress" : "I gang",
    "Done" : "Afsluttet",
    "Create your first card!" : "Opret dit første kort!",
    "Attachments" : "Vedhæftede filer",
    "File" : "Fil",
    "Card not found" : "Kort ikke fundet.",
    "Path is already shared with this card" : "Stien er allerede delt med dette kort.",
    "Invalid date, date format must be YYYY-MM-DD" : "Ikke gyldig dato - dato formatet skal være ÅÅÅÅ-MM-DD",
    "Personal planning and team project organization" : "Personlig planlægning og organisering af teamprojekter",
    "Add board" : "Tilføj tavle",
    "Card details" : "Kortdetaljer",
    "Select the board to link to a project" : "Vælg tavlen der skal linkes til et projekt",
    "Search by board title" : "Søg efter tavletitel",
    "Select board" : "Vælg tavle",
    "Move/copy card" : "Flyt/kopiér kort",
    "Select a board" : "Vælg en tavle",
    "No lists available" : "Ingen lister tilgængelige",
    "Select a list" : "Vælg en liste",
    "Move card" : "Flyt kort",
    "Copy card" : "Kopiér kort",
    "Select the card to link to a project" : "Vælg kortet der skal linkes til et projekt",
    "Link to card" : "Link til kort",
    "Select a card" : "Vælg et kort",
    "Cancel" : "Annuller",
    "This board is read only" : "Denne tavle er skrivebeskyttet",
    "Drop your files to upload" : "Slip dine filer for at uploade",
    "File already exists" : "Filen findes allerede",
    "A file with the name {filename} already exists." : "En fil med navnet {filename} eksisterer allerede.",
    "Do you want to overwrite it?" : "Vil du overskrive?",
    "Overwrite file" : "Overskriv fil",
    "Keep existing file" : "Behold den eksisterende fil",
    "Add card" : "Tilføj kort",
    "Archived cards" : "Arkiverede kort",
    "Add list" : "Tilføj liste",
    "List name" : "Listenavn",
    "Active filters" : "Aktive filtre",
    "Apply filter" : "Aktiver filter",
    "Filter by tag" : "Filtrer efter Tag",
    "Filter by assigned user" : "Filtrer efter tildelt bruger",
    "Unassigned" : "Ikke tildelt",
    "Open" : "Åbn",
    "Completed" : "Fuldført",
    "Filter by due date" : "Filtrer efter forfaldsdato",
    "Overdue" : "Overskredet",
    "Next 24 hours" : "De næste 24 timer",
    "Next 7 days" : "De næste 7 dage",
    "Next 30 days" : "De næste 30 dage",
    "No due date" : "Ingen forfaldsdato",
    "Clear filter" : "Ryd filter",
    "Hide archived cards" : "Skjul arkiverede kort",
    "Show archived cards" : "Vis arkiverede kort",
    "Toggle compact mode" : "Slå kompakt tilstand til/fra",
    "Open details" : "Mere information",
    "Details" : "Detaljer",
    "Loading board" : "Indlæser tavle",
    "Board not found" : "Tavle ikke fundet.",
    "Create a new list to add cards to this board" : "Opret en ny liste for at tilføje kort til denne tavle ",
    "Sharing" : "Deling",
    "Tags" : "Tags",
    "Deleted items" : "Slettede objekter",
    "Activity" : "Aktivitet",
    "Deleted lists" : "Slettede lister",
    "Undo" : "Fortryd",
    "Deleted cards" : "Sletttede kort",
    "Failed to create share with {displayName}" : "Kunne ikke oprette deling med {displayName}",
    "Transfer" : "Overførsel",
    "No participants found" : "Ingen deltagere fundet",
    "Board owner" : "Ejer af tavlen",
    "(Group)" : "(Gruppe)",
    "Can edit" : "Kan redigere",
    "Can share" : "Kan dele",
    "Can manage" : "Kan administrere",
    "Owner" : "Ejer",
    "Delete" : "Slet",
    "List deleted" : "Liste slettet",
    "Archive all cards" : "Arkiver alle kort",
    "Delete list" : "Slet liste",
    "Archive all cards in this list" : "Arkiver alle kort på denne liste",
    "Add a new card" : "Tilføj et nyt kort",
    "Card name" : "Kortnavn",
    "title and color value must be provided" : "Titel- og farveværdi skal angives.",
    "Edit" : "Redigér",
    "Add a new tag" : "Opret et nyt tag",
    "Board name" : "Tavlenavn",
    "Members" : "Medlemmer",
    "Assign a user to this card…" : "Tildel en bruger til dette kort...",
    "File to share" : "Fil til deling",
    "Invalid path selected" : "Ugyldig sti valgt.",
    "Upload new files" : "Upload nye filer",
    "Share from Files" : "Del fra Filer",
    "Add this attachment" : "Tilføj denne vedhæftning",
    "Show in Files" : "Vis i Filer",
    "Download" : "Download",
    "Delete Attachment" : "Slet vedhæftning",
    "Restore Attachment" : "Genskab vedhæftning",
    "Modified" : "Ændret",
    "Created" : "Oprettet",
    "The title cannot be empty." : "Titlen må ikke være tom",
    "Open in sidebar view" : "Åben i sidebjælke visning",
    "Open in bigger view" : "Åben i større visning",
    "Comments" : "Kommentarer",
    "No comments yet. Begin the discussion!" : "Ingen kommentarer endnu. Begynd diskussionen!",
    "The comment cannot be empty." : "Kommentaren må ikke være tom.",
    "The comment cannot be longer than 1000 characters." : "Kommentaren må ikke være længere end 1000 tegn.",
    "Save" : "Gem",
    "Created:" : "Oprettet:",
    "In reply to" : "Som svar til",
    "Cancel reply" : "Annuller svar",
    "Reply" : "Besvar",
    "Update" : "Opdatér",
    "Write a description …" : "Skriv en beskrivelse...",
    "Description" : "Beskrivelse",
    "(Unsaved)" : "(Ikke gemt)",
    "(Saving…)" : "(Gemmer...)",
    "Formatting help" : "Hjælp til formatering",
    "Edit description" : "Redigér beskrivelse",
    "View description" : "Se beskrivelse",
    "Add Attachment" : "Tilføj vedhæftning",
    "Choose attachment" : "Vælg en vedhæftning",
    "Select Date" : "Vælg dato",
    "Set a due date" : "Angiv en forfaldsdato",
    "Remove due date" : "Fjern forfaldsdato",
    "Mark as done" : "Marker som færdig",
    "Not done" : "Ikke færdig",
    "Unarchive card" : "Genaktiver kort",
    "Archive card" : "Arkiver kort",
    "Assign a tag to this card…" : "Tilføj et Tag til dette kort ...",
    "Create a new tag:" : "Opret et nyt tag:",
    "(group)" : "(gruppe)",
    "Edit card title" : "Redigér titel på kort",
    "Open link" : "Åben link",
    "Card deleted" : "Kort slettet",
    "Edit title" : "Redigér titel",
    "Assign to me" : "Tildel til mig",
    "Unassign myself" : "Fjern mig selv",
    "Delete card" : "Slet kort",
    "seconds ago" : "få sekunder siden",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Boost your productivity using Deck with keyboard shortcuts." : "Boost din produktivitet ved at anvende opslag med tastaturgenveje.",
    "Keyboard shortcut" : "Tastaturgenvej",
    "Action" : "Handling",
    "Shift" : "Shift",
    "Navigate between cards" : "Naviger mellem kort",
    "Close card details" : "Luk detaljer for kort",
    "Ctrl" : "Ctrl",
    "Search" : "Søg",
    "Show card filters" : "Vis kort filtre",
    "Clear card filters" : "Ryd kort filtre",
    "Card actions" : "Kort handlinger",
    "Enter" : "Indtast",
    "Open card details" : "Åbn detaljer for kort",
    "Edit the card title" : "Redigér titel på kort",
    "Assign yourself to the current card" : "Tilknyt dig selv til det aktuelle kort",
    "All boards" : "Alle tavler",
    "Archived boards" : "Arkiverede lister",
    "Shared with you" : "Delt med dig",
    "Deck settings" : "Opslagsindstillinger",
    "Use bigger card view" : "Brug større kort visning",
    "Show boards in calendar/tasks" : "Vis tavler i kalender/opgaver",
    "Cancel edit" : "Annullér redigering",
    "Board {0} deleted" : "Tavle {0} er slettet",
    "All cards" : "Alle kort",
    "Only assigned cards" : "Kun tildelte kort",
    "No reminder" : "Ingen påmindelse",
    "An error occurred" : "Der opstod en fejl",
    "Delete the board?" : "Slet tavlen?",
    "Board details" : "Tavledetaljer",
    "Edit board" : "Redigér liste",
    "Clone board" : "Klon tavle",
    "Unarchive board" : "Genaktiver tavle",
    "Archive board" : "Arkiver tavle",
    "Turn on due date reminders" : "Aktiver påmindelser om forfaldsdatoer",
    "Turn off due date reminders" : "Slå påmindelser om forfaldsdatoer fra",
    "Due date reminders" : "Påmindelser om forfaldsdatoer",
    "Assigned cards" : "Tildelte kort",
    "No notifications" : "Ingen notifikationer",
    "Delete board" : "Slet tavle",
    "Clone {boardTitle}" : "Klon {boardTitle}",
    "Clone cards" : "Klon kort",
    "Clone assignments" : "Kloningsopgaver",
    "Clone labels" : "Kloningslabels",
    "Clone due dates" : "Klon forfaldsdatoer",
    "Advanced options" : "Avancerede indstillinger",
    "Clone" : "Klon",
    "Export as CSV" : "Eksportér som CSV",
    "Export" : "Eksportér",
    "Loading filtered view" : "Indlæser filtreret visning",
    "No results found" : "Ingen resultater fundet",
    "Deck board {name}\n* Last modified on {lastMod}" : "Opslagstavle {name}\n* Senest ændret den {lastMod}",
    "Create card" : "Opret kort",
    "Create a new card" : "Opret et nyt kort",
    "Creating the new card …" : "Opretter det nye kort ...",
    "Close" : "Luk",
    "No upcoming cards" : "Ingen kommende kort",
    "upcoming cards" : "kommende kort",
    "New card" : "Nyt kort",
    "Link to a board" : "Link til tavle",
    "Link to a card" : "Link til et kort",
    "Message from {author} in {conversationName}" : "Besked fra {author} i {conversationName}",
    "Something went wrong" : "Noget gik galt",
    "Failed to upload {name}" : "Kunne ikke uploade {name}",
    "Maximum file size of {size} exceeded" : "Maksimal filstørrelse {size} overskredet",
    "Due date" : "Forfaldsdato",
    "Error creating the share" : "Fejl ved oprettelse af delt drev",
    "Share with a Deck card" : "Del med et opslagskort",
    "Share {file} with a Deck card" : "Del {file} med et opslagskort",
    "Share" : "Del",
    "Personal" : "Personligt",
    "To do" : "To do",
    "Doing" : "Igang",
    "Example Task 3" : "Eksempel opgave 3",
    "Example Task 2" : "Eksempel opgave 2",
    "Example Task 1" : "Eksempel opgave 1",
    "Move card to another board" : "Flyt kort til en anden tavle",
    "Today" : "I dag",
    "Tomorrow" : "I morgen",
    "No due" : "Ikke forfalden"
},
"nplurals=2; plural=(n != 1);");
